Crate pingap_acme

Crate pingap_acme 

Enums

Error
Errors that can occur during ACME operations

Statics

LOG_TARGET
Category name for ACME-related logging

Traits

AcmeDnsTask
Acme DNS task

Functions

handle_lets_encrypt
Handles the HTTP-01 challenge verification for Let’s Encrypt. This function:
new_lets_encrypt_service
Create a Let’s Encrypt service to generate the certificate, and regenerate if the certificate is invalid or will be expired.

Type Aliases

Result
Convenience type alias for Results with our Error type